'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const client = require('@prismicio/client');
const core = require('@apollo/client/core');

const createPrismicLink = (config) => {
  const {
    repositoryName: providedRepositoryName,
    fetch,
    accessToken,
    apiEndpoint: providedApiEndpoint,
    uri: providedURI,
    ...options
  } = config;
  let repositoryName = providedRepositoryName;
  if (!repositoryName && providedURI) {
    repositoryName = client.getRepositoryName(providedURI);
  }
  if (!repositoryName) {
    throw new Error("At least one of the following options are required for createPrismicLink(): repositoryName, uri. If a repositoryName option is not given, the uri option must be a standard, non-proxied Prismic GraphQL API URL including the repository name.");
  }
  const uri = providedURI || client.getGraphQLEndpoint(repositoryName);
  const apiEndpoint = providedApiEndpoint || client.getRepositoryEndpoint(repositoryName);
  const client$1 = client.createClient(apiEndpoint, {
    fetch,
    accessToken
  });
  return core.createHttpLink({
    uri,
    fetch: client$1.graphqlFetch,
    useGETForQueries: true,
    ...options
  });
};

const PrismicLink = createPrismicLink;

exports.PrismicLink = PrismicLink;
exports.createPrismicLink = createPrismicLink;
//# sourceMappingURL=index.cjs.map
